"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.parseConfigFile = exports.getArgs = exports.getDefaultConfigFile = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const yargs_1 = __importDefault(require("yargs"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const utils_1 = require("@terascope/utils");
function getDefaultConfigFile() {
    const cwd = process.cwd();
    if (process.env.TERAFOUNDATION_CONFIG) {
        return path_1.default.resolve(process.env.TERAFOUNDATION_CONFIG);
    }
    if (fs_1.default.existsSync('/app/config/config.yaml')) {
        return '/app/config/config.yaml';
    }
    if (fs_1.default.existsSync('/app/config/config.yml')) {
        return '/app/config/config.yml';
    }
    if (fs_1.default.existsSync('/app/config/config.json')) {
        return '/app/config/config.json';
    }
    if (fs_1.default.existsSync(path_1.default.join(cwd, './config.yaml'))) {
        return path_1.default.join(cwd, './config.yaml');
    }
    if (fs_1.default.existsSync(path_1.default.join(cwd, './config.yml'))) {
        return path_1.default.join(cwd, './config.yml');
    }
    if (fs_1.default.existsSync(path_1.default.join(cwd, './config.json'))) {
        return path_1.default.join(cwd, './config.json');
    }
    return undefined;
}
exports.getDefaultConfigFile = getDefaultConfigFile;
function getArgs(defaultConfigFile) {
    const { argv } = yargs_1.default.usage('Usage: $0 [options]')
        .version()
        .alias('v', 'version')
        .help()
        .alias('h', 'help')
        .detectLocale(false)
        .option('configfile', {
        alias: 'c',
        default: getDefaultConfigFile(),
        describe: `Terafoundation configuration file to load.
                        Defaults to env TERAFOUNDATION_CONFIG.`,
        coerce(arg) {
            return parseConfigFile(arg || defaultConfigFile);
        }
    })
        .wrap(yargs_1.default.terminalWidth());
    return argv;
}
exports.getArgs = getArgs;
function parseConfigFile(file) {
    const configFile = file ? path_1.default.resolve(file) : undefined;
    if (!configFile || !fs_1.default.existsSync(configFile)) {
        throw new Error(`Could not find a usable config file at the path: ${configFile}`);
    }
    if (['.yaml', '.yml'].includes(path_1.default.extname(configFile))) {
        return js_yaml_1.default.load(fs_1.default.readFileSync(configFile, 'utf8'));
    }
    return (0, utils_1.cloneDeep)(require(configFile));
}
exports.parseConfigFile = parseConfigFile;
//# sourceMappingURL=sysconfig.js.map